==> vue-renderer-1.0.1.tgz: package/src/index.js <==
const serialize = require('serialize-javascript');
const webpack = require("webpack");
const MemoryFS = require('memory-fs');
const vsr = require('vue-server-renderer');

/*
* VUE_ENV=server is required by the SSR.
*/

process.env.VUE_ENV = 'server';

/*
* Core class for rendering Vue application on the server.
*/

exports.VueRenderer = class {

  /*
  * Class constructor
  */

  constructor () {
    this.fs = new MemoryFS();
  }

  /*
  * Serialize javascript object.
  */

  serialize (src, options) {
    return serialize(src, options);
  }

  /*
  * Creates a new Webpack configuration object.
  */

  buildWebpackConfig (defaults) {
    return {
      entry: `./src/client/server-entry.js`,
      module: {
        loaders: [
          {test: /\.vue$/, loader: 'vue'},
          {test: /\.js$/, loader: 'babel', exclude: /node_modules/},
          {test: /\.json$/, loader: 'json'}
        ]
      },
      output: {
        path: '/',
        filename: 'bundle.js',
        libraryTarget: 'commonjs2'
      },
      plugins: [
        new webpack.DefinePlugin({
          'process.env.NODE_ENV': JSON.stringify('production'),
          'process.env.VUE_ENV': JSON.stringify('server')
        })
      ],
      target: 'node'
    };
  }

  /*
  * Creates a new application bundle renderer.
  */

  create ({config, ctx, cache}) {
    return new Promise((resolve, reject) => {
      const settings = this.buildWebpackConfig(config);

      const compiler = webpack(settings);
      compiler.outputFileSystem = this.fs;
      compiler.run((err, stats) => {
        if (err) {
          reject(err);
        }
        else {
          let code = this.fs.readFileSync('/bundle.js', 'utf8');
          let renderer = vsr.createBundleRenderer(code);
          resolve(renderer);
        }
      });
    });
  }

  /*
  * Returns a promise which renders the application and returns the course as
  * HTML stream.
  */

  renderToStream ({config, ctx, cache}) {
    return this.create({config, ctx, cache}).then((renderer) => {
      let page = renderer.renderToStream(ctx);
      page.once('data', (chunk) => page.emit('init', ctx));
      return page;
    });
  }

  /*
  * Returns a promise which renders the application and returns the course as
  * HTML string.
  */

  renderToString ({config, ctx, cache}) {
    return this.create({config, ctx, cache}).then((renderer) => {
      return new Promise((resolve, reject) => {
        renderer.renderToString(ctx, (err, html) => {
          if (err) {
            reject(err);
          }
          else {
            resolve(html);
          }
        });
      });
    });
  }

}

==> vue-renderer-1.0.2.tgz: package/src/index.js <==
const serialize = require('serialize-javascript');
const webpack = require("webpack");
const MemoryFS = require('memory-fs');
const vsr = require('vue-server-renderer');

/*
* VUE_ENV=server is required by the SSR.
*/

process.env.VUE_ENV = 'server';

/*
* Core class for rendering Vue application on the server.
*/

exports.VueRenderer = class {

  /*
  * Class constructor
  */

  constructor () {
    this.fs = new MemoryFS();
  }

  /*
  * Serialize javascript object.
  */

  serialize (src, options) {
    return serialize(src, options);
  }

  /*
  * Creates a new Webpack configuration object.
  */

  buildWebpackConfig (defaults) {
    return {
      entry: `./src/client/server-entry.js`,
      module: {
        loaders: [
          {test: /\.vue$/, loader: 'vue'},
          {test: /\.js$/, loader: 'babel', exclude: /node_modules/},
          {test: /\.json$/, loader: 'json'}
        ]
      },
      output: {
        path: '/',
        filename: 'bundle.js',
        libraryTarget: 'commonjs2'
      },
      plugins: [
        new webpack.DefinePlugin({
          'process.env.NODE_ENV': JSON.stringify('production'),
          'process.env.VUE_ENV': JSON.stringify('server')
        })
      ],
      target: 'node'
    };
  }

  createCompiler() {
    const settings = this.buildWebpackConfig(config);
    return webpack(settings);
  }

  /*
  * Creates a new application bundle renderer.
  */

  create ({config, ctx, cache}) {
    return new Promise((resolve, reject) => {
      const compiler = this.createCompiler();
      compiler.outputFileSystem = this.fs;
      compiler.run((err, stats) => {
        if (err) {
          reject(err);
        }
        else {
          let code = this.fs.readFileSync('/bundle.js', 'utf8');
          let renderer = vsr.createBundleRenderer(code);
          resolve(renderer);
        }
      });
    });
  }

  /*
  * Returns a promise which renders the application and returns the course as
  * HTML stream.
  */

  renderToStream ({config, ctx, cache}) {
    return this.create({config, ctx, cache}).then((renderer) => {
      let page = renderer.renderToStream(ctx);
      page.once('data', (chunk) => page.emit('init', ctx));
      return page;
    });
  }

  /*
  * Returns a promise which renders the application and returns the course as
  * HTML string.
  */

  renderToString ({config, ctx, cache}) {
    return this.create({config, ctx, cache}).then((renderer) => {
      return new Promise((resolve, reject) => {
        renderer.renderToString(ctx, (err, html) => {
          if (err) {
            reject(err);
          }
          else {
            resolve(html);
          }
        });
      });
    });
  }

}
